# mirascope.core.base.call_params

## `BaseCallParams`

!!! note "Base Class Definition"

    This class is simply a means of binding type variables to ensure they are call params, but the class itself is empty. We do this because you cannot bind a type variable to a base `TypedDict` type and must create your own subclass to do so.

::: mirascope.core.base.call_params.BaseCallParams
